/*
 * @(#)SRLayout.java	1.02 2 Jan 2002
 *
 * Copyright John Redmond (John.Redmond@mq.edu.au).
 * 
 * This software is freely available for commercial and non-commercial purposes.
 * Acknowledgement of its source would be appreciated, but is not required.
 * 
 */

package au.com.pegasustech.demos.layout;

//import java.util.*;
import java.awt.*;

public class SRLayout extends SGLayout {

  /**
   * Creates a layout with the specified number of columns
   * and default alignments and gaps.
   * <p>
   * horizontal gaps are set to 0 and
   * X- and Y-alignments are set to FILL.
   * @param     cols   the columns.
   */
  public SRLayout(int columns) {
    super(1, columns);
  }

  /**
   * Creates a layout with the specified number of columns
   * and specified gap.
   * <p>
   * horizontal and vertical gaps are set to 0 and
   * X- and Y-alignments are set to FILL.
   * @param     cols   the columns.
   * @param     gap   the horizontal gap, in pixels.
   */
  public SRLayout(int columns, int gap) {
    super(1, columns, gap, 0);
  }

  /**
   * Creates a layout with the specified number of columns
   * and specified alignments and gaps.
   * <p>
   * horizontal and vertical gaps are set to 0 and
   * X- and Y-alignments are set to FILL.
   * @param     cols   the columns.
   * @param     gap   the horizontal gap, in pixels.
   */
  public SRLayout(int columns, int hAlignment, int vAlignment, int gap) {
    super(1, columns, hAlignment, vAlignment, gap, 0);
  }

  /**
   * Set up alignment for a specific cell.
   * <p>
   * @param     index the cell number.
   * @param     hAlignment  the X-alignment for the cell.
   * @param     vAlignment  the Y-alignment for the cell.
   */
  public void setAlignment(int column, int hAlignment, int vAlignment) {
    setColumnAlignment(column, hAlignment, vAlignment);
  }

  /**
   * Set up scale value for a specific cell.
   * <p>
   * @param     index the cell number.
   * @param     scale  the scale value for the column.
   */
  public void setScale(int column, double scale) {
    setColumnScale(column, scale);
  }
/*
  public Dimension preferredLayoutSize(Container parent) {
    synchronized (parent.getTreeLock()) {
      int ncomponents = parent.getComponentCount();
      int totalWidth = leftBorder + rightBorder;
      int totalHeight = topBorder + bottomBorder;
      int minWidth = 0, minHeight = 0;

//      int prefWidth = 0, prefHeight = 0;
      // get max preferred width and height
      for (int j = 0; j < cols; j++) {
        if (j >= ncomponents) continue;

        Component comp = parent.getComponent(j);
        Dimension d = comp.getPreferredSize();
        int width = d.width;
        if (width < minW) width = minW;
        if (width > minWidth) minWidth = width;
        totalWidth += width;// * columnScale[j];

        int height = d.height;
        if (height < minH) height = minH;
        if (height > minHeight) minHeight = height;
      }
      totalWidth += (cols - 1) * hgap;
      totalHeight += minHeight;
System.out.println("Pref: " + minWidth + " " + minHeight);
System.out.println("Total Pref: " + totalWidth + " " + totalHeight);

//    return new Dimension(totalWidth, totalHeight);
      return new Dimension(290, 27);
//      return parent.getSize();
    }
  }

  public Dimension minimumLayoutSize(Container parent) {
    synchronized (parent.getTreeLock()) {
      int ncomponents = parent.getComponentCount();
      int totalWidth = leftBorder + rightBorder;
      int totalHeight = topBorder + bottomBorder;
      int minWidth = 0, minHeight = 0;

//      int prefWidth = 0, prefHeight = 0;
      // get max preferred width and height
      for (int j = 0; j < cols; j++) {
        if (j >= ncomponents) continue;

        int minSetWidth = columnSizes[j];
        Component comp = parent.getComponent(j);
        Dimension d = comp.getMinimumSize();
        int width = d.width;
        if (width < minW) width = minW;
        if (width > minWidth) minWidth = width;
        if (minSetWidth > width) width = minSetWidth;
        totalWidth += width;// * columnScale[j];

        int height = d.height;
        if (height < minH) height = minH;
        if (height > minHeight) minHeight = height;
      }
      totalWidth += (cols - 1) * hgap;
      totalHeight += minHeight;
System.out.println("Min: " + minWidth + " " + minHeight);
System.out.println("Total Min: " + totalWidth + " " + totalHeight);

    return new Dimension(totalWidth, totalHeight);
//      return new Dimension(250, 27);
    }
  }

  public void layoutContainer(Container parent) {
    int maxWidth = parent.getSize().width - leftBorder - rightBorder;
    int maxHeight = parent.getSize().height - topBorder - bottomBorder;
    int nComps = parent.getComponentCount();
    int previousWidth = 0, previousHeight = 0;
    int x = leftBorder, y = topBorder;
    int rowh = 0, start = 0;

    allocateMaxSizes(parent);

    for (int j = 0; j < cols; j++) {
      if (j > nComps - 1) continue;

      Component c = parent.getComponent(j);
      if (c.isVisible())
        setComponentBounds(c, 0, j, x, topBorder);
      x += columnSizes[j] + hgap;
    }
  }
*/
}
